==> ne_2.3.orig.tar.gz: ne-2.3/src/names.h <==
/* Extern's for names and abbreviations of all the commands.

	Copyright (C) 1993-1998 Sebastiano Vigna 
	Copyright (C) 1999-2011 Todd M. Lewis and Sebastiano Vigna

	This file is part of ne, the nice editor.

	This library is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 3 of the License, or (at your
	option) any later version.

	This library is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
	or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
	for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, see <http://www.gnu.org/licenses/>.  */


extern const char ABOUT_NAME[];
extern const char ABOUT_ABBREV[];

extern const char ADJUSTVIEW_NAME[];
extern const char ADJUSTVIEW_ABBREV[];

extern const char ALERT_NAME[];
extern const char ALERT_ABBREV[];

extern const char AUTOCOMPLETE_NAME[];
extern const char AUTOCOMPLETE_ABBREV[];

extern const char AUTOINDENT_NAME[];
extern const char AUTOINDENT_ABBREV[];

extern const char AUTOMATCHBRACKET_NAME[];
extern const char AUTOMATCHBRACKET_ABBREV[];

extern const char AUTOPREFS_NAME[];
extern const char AUTOPREFS_ABBREV[];

extern const char BACKSPACE_NAME[];
extern const char BACKSPACE_ABBREV[];

extern const char BEEP_NAME[];
extern const char BEEP_ABBREV[];

extern const char BINARY_NAME[];
extern const char BINARY_ABBREV[];

extern const char CAPITALIZE_NAME[];
extern const char CAPITALIZE_ABBREV[];

extern const char CASESEARCH_NAME[];
extern const char CASESEARCH_ABBREV[];

extern const char CENTER_NAME[];
extern const char CENTER_ABBREV[];

extern const char CLEAR_NAME[];
extern const char CLEAR_ABBREV[];

extern const char CLIPNUMBER_NAME[];
extern const char CLIPNUMBER_ABBREV[];

extern const char CLOSEDOC_NAME[];
extern const char CLOSEDOC_ABBREV[];

extern const char COPY_NAME[];
extern const char COPY_ABBREV[];

extern const char CRLF_NAME[];
extern const char CRLF_ABBREV[];

extern const char CUT_NAME[];
extern const char CUT_ABBREV[];

extern const char DELETECHAR_NAME[];
extern const char DELETECHAR_ABBREV[];

extern const char DELETEEOL_NAME[];
extern const char DELETEEOL_ABBREV[];

extern const char DELETELINE_NAME[];
extern const char DELETELINE_ABBREV[];

extern const char DELETENEXTWORD_NAME[];
extern const char DELETENEXTWORD_ABBREV[];

extern const char DELETEPREVWORD_NAME[];
extern const char DELETEPREVWORD_ABBREV[];

extern const char DOUNDO_NAME[];
extern const char DOUNDO_ABBREV[];

extern const char ERASE_NAME[];
extern const char ERASE_ABBREV[];

extern const char ESCAPE_NAME[];
extern const char ESCAPE_ABBREV[];

extern const char ESCAPETIME_NAME[];
extern const char ESCAPETIME_ABBREV[];

extern const char EXEC_NAME[];
extern const char EXEC_ABBREV[];

extern const char EXIT_NAME[];
extern const char EXIT_ABBREV[];

extern const char FASTGUI_NAME[];
extern const char FASTGUI_ABBREV[];

extern const char FIND_NAME[];
extern const char FIND_ABBREV[];

extern const char FINDREGEXP_NAME[];
extern const char FINDREGEXP_ABBREV[];

extern const char FLAGS_NAME[];
extern const char FLAGS_ABBREV[];

extern const char FLASH_NAME[];
extern const char FLASH_ABBREV[];

extern const char FREEFORM_NAME[];
extern const char FREEFORM_ABBREV[];

extern const char GOTOBOOKMARK_NAME[];
extern const char GOTOBOOKMARK_ABBREV[];

extern const char GOTOCOLUMN_NAME[];
extern const char GOTOCOLUMN_ABBREV[];

extern const char GOTOLINE_NAME[];
extern const char GOTOLINE_ABBREV[];

extern const char GOTOMARK_NAME[];
extern const char GOTOMARK_ABBREV[];

extern const char HELP_NAME[];
extern const char HELP_ABBREV[];

extern const char HEXCODE_NAME[];
extern const char HEXCODE_ABBREV[];

extern const char INSERT_NAME[];
extern const char INSERT_ABBREV[];

extern const char INSERTCHAR_NAME[];
extern const char INSERTCHAR_ABBREV[];

extern const char INSERTLINE_NAME[];
extern const char INSERTLINE_ABBREV[];

extern const char INSERTSTRING_NAME[];
extern const char INSERTSTRING_ABBREV[];

extern const char INSERTTAB_NAME[];
extern const char INSERTTAB_ABBREV[];

extern const char KEYCODE_NAME[];
extern const char KEYCODE_ABBREV[];

extern const char LINEDOWN_NAME[];
extern const char LINEDOWN_ABBREV[];

extern const char LINEUP_NAME[];
extern const char LINEUP_ABBREV[];

extern const char LOADAUTOPREFS_NAME[];
extern const char LOADAUTOPREFS_ABBREV[];

extern const char LOADPREFS_NAME[];
extern const char LOADPREFS_ABBREV[];

extern const char MACRO_NAME[];
extern const char MACRO_ABBREV[];

extern const char MARK_NAME[];
extern const char MARK_ABBREV[];

extern const char MARKVERT_NAME[];
extern const char MARKVERT_ABBREV[];

extern const char MATCHBRACKET_NAME[];
extern const char MATCHBRACKET_ABBREV[];

extern const char MODIFIED_NAME[];
extern const char MODIFIED_ABBREV[];

extern const char MOVEBOS_NAME[];
extern const char MOVEBOS_ABBREV[];

extern const char MOVEEOF_NAME[];
extern const char MOVEEOF_ABBREV[];

extern const char MOVEEOL_NAME[];
extern const char MOVEEOL_ABBREV[];

extern const char MOVEEOW_NAME[];
extern const char MOVEEOW_ABBREV[];

extern const char MOVEINCDOWN_NAME[];
extern const char MOVEINCDOWN_ABBREV[];

extern const char MOVEINCUP_NAME[];
extern const char MOVEINCUP_ABBREV[];

extern const char MOVELEFT_NAME[];
extern const char MOVELEFT_ABBREV[];

extern const char MOVERIGHT_NAME[];
extern const char MOVERIGHT_ABBREV[];

extern const char MOVESOF_NAME[];
extern const char MOVESOF_ABBREV[];

extern const char MOVESOL_NAME[];
extern const char MOVESOL_ABBREV[];

extern const char MOVETOS_NAME[];
extern const char MOVETOS_ABBREV[];

extern const char NEWDOC_NAME[];
extern const char NEWDOC_ABBREV[];

extern const char NEXTDOC_NAME[];
extern const char NEXTDOC_ABBREV[];

extern const char NEXTPAGE_NAME[];
extern const char NEXTPAGE_ABBREV[];

extern const char NEXTWORD_NAME[];
extern const char NEXTWORD_ABBREV[];

extern const char NOFILEREQ_NAME[];
extern const char NOFILEREQ_ABBREV[];

extern const char NOP_NAME[];
extern const char NOP_ABBREV[];

extern const char OPEN_NAME[];
extern const char OPEN_ABBREV[];

extern const char OPENCLIP_NAME[];
extern const char OPENCLIP_ABBREV[];

extern const char OPENMACRO_NAME[];
extern const char OPENMACRO_ABBREV[];

extern const char OPENNEW_NAME[];
extern const char OPENNEW_ABBREV[];

extern const char PAGEDOWN_NAME[];
extern const char PAGEDOWN_ABBREV[];

extern const char PAGEUP_NAME[];
extern const char PAGEUP_ABBREV[];

extern const char PARAGRAPH_NAME[];
extern const char PARAGRAPH_ABBREV[];

extern const char PASTE_NAME[];
extern const char PASTE_ABBREV[];

extern const char PASTEVERT_NAME[];
extern const char PASTEVERT_ABBREV[];

extern const char PLAY_NAME[];
extern const char PLAY_ABBREV[];

extern const char POPPREFS_NAME[];
extern const char POPPREFS_ABBREV[];

extern const char PRESERVECR_NAME[];
extern const char PRESERVECR_ABBREV[];

extern const char PREVDOC_NAME[];
extern const char PREVDOC_ABBREV[];

extern const char PREVPAGE_NAME[];
extern const char PREVPAGE_ABBREV[];

extern const char PREVWORD_NAME[];
extern const char PREVWORD_ABBREV[];

extern const char PUSHPREFS_NAME[];
extern const char PUSHPREFS_ABBREV[];

extern const char QUIT_NAME[];
extern const char QUIT_ABBREV[];

extern const char READONLY_NAME[];
extern const char READONLY_ABBREV[];

extern const char RECORD_NAME[];
extern const char RECORD_ABBREV[];

extern const char REDO_NAME[];
extern const char REDO_ABBREV[];

extern const char REFRESH_NAME[];
extern const char REFRESH_ABBREV[];

extern const char REPEATLAST_NAME[];
extern const char REPEATLAST_ABBREV[];

extern const char REPLACE_NAME[];
extern const char REPLACE_ABBREV[];

extern const char REPLACEALL_NAME[];
extern const char REPLACEALL_ABBREV[];

extern const char REPLACEONCE_NAME[];
extern const char REPLACEONCE_ABBREV[];

extern const char REQUESTORDER_NAME[];
extern const char REQUESTORDER_ABBREV[];

extern const char RIGHTMARGIN_NAME[];
extern const char RIGHTMARGIN_ABBREV[];

extern const char SAVE_NAME[];
extern const char SAVE_ABBREV[];

extern const char SAVEAS_NAME[];
extern const char SAVEAS_ABBREV[];

extern const char SAVEAUTOPREFS_NAME[];
extern const char SAVEAUTOPREFS_ABBREV[];

extern const char SAVECLIP_NAME[];
extern const char SAVECLIP_ABBREV[];

extern const char SAVEDEFPREFS_NAME[];
extern const char SAVEDEFPREFS_ABBREV[];

extern const char SAVEMACRO_NAME[];
extern const char SAVEMACRO_ABBREV[];

extern const char SAVEPREFS_NAME[];
extern const char SAVEPREFS_ABBREV[];

extern const char SEARCHBACK_NAME[];
extern const char SEARCHBACK_ABBREV[];

extern const char SELECTDOC_NAME[];
extern const char SELECTDOC_ABBREV[];

extern const char SETBOOKMARK_NAME[];
extern const char SETBOOKMARK_ABBREV[];

extern const char STATUSBAR_NAME[];
extern const char STATUSBAR_ABBREV[];

extern const char SUSPEND_NAME[];
extern const char SUSPEND_ABBREV[];

extern const char SYNTAX_NAME[];
extern const char SYNTAX_ABBREV[];

extern const char SYSTEM_NAME[];
extern const char SYSTEM_ABBREV[];

extern const char TABS_NAME[];
extern const char TABS_ABBREV[];

extern const char TABSIZE_NAME[];
extern const char TABSIZE_ABBREV[];

extern const char THROUGH_NAME[];
extern const char THROUGH_ABBREV[];

extern const char TOGGLESEOF_NAME[];
extern const char TOGGLESEOF_ABBREV[];

extern const char TOGGLESEOL_NAME[];
extern const char TOGGLESEOL_ABBREV[];

extern const char TOLOWER_NAME[];
extern const char TOLOWER_ABBREV[];

extern const char TOUPPER_NAME[];
extern const char TOUPPER_ABBREV[];

extern const char TURBO_NAME[];
extern const char TURBO_ABBREV[];

extern const char UNDELLINE_NAME[];
extern const char UNDELLINE_ABBREV[];

extern const char UNDO_NAME[];
extern const char UNDO_ABBREV[];

extern const char UNLOADMACROS_NAME[];
extern const char UNLOADMACROS_ABBREV[];

extern const char UNSETBOOKMARK_NAME[];
extern const char UNSETBOOKMARK_ABBREV[];

extern const char UTF8_NAME[];
extern const char UTF8_ABBREV[];

extern const char UTF8AUTO_NAME[];
extern const char UTF8AUTO_ABBREV[];

extern const char UTF8IO_NAME[];
extern const char UTF8IO_ABBREV[];

extern const char VERBOSEMACROS_NAME[];
extern const char VERBOSEMACROS_ABBREV[];

extern const char VISUALBELL_NAME[];
extern const char VISUALBELL_ABBREV[];

extern const char WORDWRAP_NAME[];
extern const char WORDWRAP_ABBREV[];


/* These are extras that are very useful in the default menus and key bindings. */
extern const char PLAYONCE_ABBREV[];
extern const char MIDDLEVIEW_ABBREV[];

/* This is the NULL-terminated, ordered list of names, useful for help etc. */

extern const char * const command_names[ACTION_COUNT+1];

/* This file was automatically generated by info2src.pl. */

==> ne_2.4.orig.tar.gz: ne-2.4/src/names.h <==
/* Extern's for names and abbreviations of all the commands.

	Copyright (C) 1993-1998 Sebastiano Vigna 
	Copyright (C) 1999-2012 Todd M. Lewis and Sebastiano Vigna

	This file is part of ne, the nice editor.

	This library is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 3 of the License, or (at your
	option) any later version.

	This library is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
	or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
	for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, see <http://www.gnu.org/licenses/>.  */


extern const char ABOUT_NAME[];
extern const char ABOUT_ABBREV[];

extern const char ADJUSTVIEW_NAME[];
extern const char ADJUSTVIEW_ABBREV[];

extern const char ALERT_NAME[];
extern const char ALERT_ABBREV[];

extern const char ATOMICUNDO_NAME[];
extern const char ATOMICUNDO_ABBREV[];

extern const char AUTOCOMPLETE_NAME[];
extern const char AUTOCOMPLETE_ABBREV[];

extern const char AUTOINDENT_NAME[];
extern const char AUTOINDENT_ABBREV[];

extern const char AUTOMATCHBRACKET_NAME[];
extern const char AUTOMATCHBRACKET_ABBREV[];

extern const char AUTOPREFS_NAME[];
extern const char AUTOPREFS_ABBREV[];

extern const char BACKSPACE_NAME[];
extern const char BACKSPACE_ABBREV[];

extern const char BEEP_NAME[];
extern const char BEEP_ABBREV[];

extern const char BINARY_NAME[];
extern const char BINARY_ABBREV[];

extern const char CAPITALIZE_NAME[];
extern const char CAPITALIZE_ABBREV[];

extern const char CASESEARCH_NAME[];
extern const char CASESEARCH_ABBREV[];

extern const char CENTER_NAME[];
extern const char CENTER_ABBREV[];

extern const char CLEAR_NAME[];
extern const char CLEAR_ABBREV[];

extern const char CLIPNUMBER_NAME[];
extern const char CLIPNUMBER_ABBREV[];

extern const char CLOSEDOC_NAME[];
extern const char CLOSEDOC_ABBREV[];

extern const char COPY_NAME[];
extern const char COPY_ABBREV[];

extern const char CRLF_NAME[];
extern const char CRLF_ABBREV[];

extern const char CUT_NAME[];
extern const char CUT_ABBREV[];

extern const char DELETECHAR_NAME[];
extern const char DELETECHAR_ABBREV[];

extern const char DELETEEOL_NAME[];
extern const char DELETEEOL_ABBREV[];

extern const char DELETELINE_NAME[];
extern const char DELETELINE_ABBREV[];

extern const char DELETENEXTWORD_NAME[];
extern const char DELETENEXTWORD_ABBREV[];

extern const char DELETEPREVWORD_NAME[];
extern const char DELETEPREVWORD_ABBREV[];

extern const char DOUNDO_NAME[];
extern const char DOUNDO_ABBREV[];

extern const char ERASE_NAME[];
extern const char ERASE_ABBREV[];

extern const char ESCAPE_NAME[];
extern const char ESCAPE_ABBREV[];

extern const char ESCAPETIME_NAME[];
extern const char ESCAPETIME_ABBREV[];

extern const char EXEC_NAME[];
extern const char EXEC_ABBREV[];

extern const char EXIT_NAME[];
extern const char EXIT_ABBREV[];

extern const char FASTGUI_NAME[];
extern const char FASTGUI_ABBREV[];

extern const char FIND_NAME[];
extern const char FIND_ABBREV[];

extern const char FINDREGEXP_NAME[];
extern const char FINDREGEXP_ABBREV[];

extern const char FLAGS_NAME[];
extern const char FLAGS_ABBREV[];

extern const char FLASH_NAME[];
extern const char FLASH_ABBREV[];

extern const char FREEFORM_NAME[];
extern const char FREEFORM_ABBREV[];

extern const char GOTOBOOKMARK_NAME[];
extern const char GOTOBOOKMARK_ABBREV[];

extern const char GOTOCOLUMN_NAME[];
extern const char GOTOCOLUMN_ABBREV[];

extern const char GOTOLINE_NAME[];
extern const char GOTOLINE_ABBREV[];

extern const char GOTOMARK_NAME[];
extern const char GOTOMARK_ABBREV[];

extern const char HELP_NAME[];
extern const char HELP_ABBREV[];

extern const char HEXCODE_NAME[];
extern const char HEXCODE_ABBREV[];

extern const char INSERT_NAME[];
extern const char INSERT_ABBREV[];

extern const char INSERTCHAR_NAME[];
extern const char INSERTCHAR_ABBREV[];

extern const char INSERTLINE_NAME[];
extern const char INSERTLINE_ABBREV[];

extern const char INSERTSTRING_NAME[];
extern const char INSERTSTRING_ABBREV[];

extern const char INSERTTAB_NAME[];
extern const char INSERTTAB_ABBREV[];

extern const char KEYCODE_NAME[];
extern const char KEYCODE_ABBREV[];

extern const char LINEDOWN_NAME[];
extern const char LINEDOWN_ABBREV[];

extern const char LINEUP_NAME[];
extern const char LINEUP_ABBREV[];

extern const char LOADAUTOPREFS_NAME[];
extern const char LOADAUTOPREFS_ABBREV[];

extern const char LOADPREFS_NAME[];
extern const char LOADPREFS_ABBREV[];

extern const char MACRO_NAME[];
extern const char MACRO_ABBREV[];

extern const char MARK_NAME[];
extern const char MARK_ABBREV[];

extern const char MARKVERT_NAME[];
extern const char MARKVERT_ABBREV[];

extern const char MATCHBRACKET_NAME[];
extern const char MATCHBRACKET_ABBREV[];

extern const char MODIFIED_NAME[];
extern const char MODIFIED_ABBREV[];

extern const char MOVEBOS_NAME[];
extern const char MOVEBOS_ABBREV[];

extern const char MOVEEOF_NAME[];
extern const char MOVEEOF_ABBREV[];

extern const char MOVEEOL_NAME[];
extern const char MOVEEOL_ABBREV[];

extern const char MOVEEOW_NAME[];
extern const char MOVEEOW_ABBREV[];

extern const char MOVEINCDOWN_NAME[];
extern const char MOVEINCDOWN_ABBREV[];

extern const char MOVEINCUP_NAME[];
extern const char MOVEINCUP_ABBREV[];

extern const char MOVELEFT_NAME[];
extern const char MOVELEFT_ABBREV[];

extern const char MOVERIGHT_NAME[];
extern const char MOVERIGHT_ABBREV[];

extern const char MOVESOF_NAME[];
extern const char MOVESOF_ABBREV[];

extern const char MOVESOL_NAME[];
extern const char MOVESOL_ABBREV[];

extern const char MOVETOS_NAME[];
extern const char MOVETOS_ABBREV[];

extern const char NEWDOC_NAME[];
extern const char NEWDOC_ABBREV[];

extern const char NEXTDOC_NAME[];
extern const char NEXTDOC_ABBREV[];

extern const char NEXTPAGE_NAME[];
extern const char NEXTPAGE_ABBREV[];

extern const char NEXTWORD_NAME[];
extern const char NEXTWORD_ABBREV[];

extern const char NOFILEREQ_NAME[];
extern const char NOFILEREQ_ABBREV[];

extern const char NOP_NAME[];
extern const char NOP_ABBREV[];

extern const char OPEN_NAME[];
extern const char OPEN_ABBREV[];

extern const char OPENCLIP_NAME[];
extern const char OPENCLIP_ABBREV[];

extern const char OPENMACRO_NAME[];
extern const char OPENMACRO_ABBREV[];

extern const char OPENNEW_NAME[];
extern const char OPENNEW_ABBREV[];

extern const char PAGEDOWN_NAME[];
extern const char PAGEDOWN_ABBREV[];

extern const char PAGEUP_NAME[];
extern const char PAGEUP_ABBREV[];

extern const char PARAGRAPH_NAME[];
extern const char PARAGRAPH_ABBREV[];

extern const char PASTE_NAME[];
extern const char PASTE_ABBREV[];

extern const char PASTEVERT_NAME[];
extern const char PASTEVERT_ABBREV[];

extern const char PLAY_NAME[];
extern const char PLAY_ABBREV[];

extern const char POPPREFS_NAME[];
extern const char POPPREFS_ABBREV[];

extern const char PRESERVECR_NAME[];
extern const char PRESERVECR_ABBREV[];

extern const char PREVDOC_NAME[];
extern const char PREVDOC_ABBREV[];

extern const char PREVPAGE_NAME[];
extern const char PREVPAGE_ABBREV[];

extern const char PREVWORD_NAME[];
extern const char PREVWORD_ABBREV[];

extern const char PUSHPREFS_NAME[];
extern const char PUSHPREFS_ABBREV[];

extern const char QUIT_NAME[];
extern const char QUIT_ABBREV[];

extern const char READONLY_NAME[];
extern const char READONLY_ABBREV[];

extern const char RECORD_NAME[];
extern const char RECORD_ABBREV[];

extern const char REDO_NAME[];
extern const char REDO_ABBREV[];

extern const char REFRESH_NAME[];
extern const char REFRESH_ABBREV[];

extern const char REPEATLAST_NAME[];
extern const char REPEATLAST_ABBREV[];

extern const char REPLACE_NAME[];
extern const char REPLACE_ABBREV[];

extern const char REPLACEALL_NAME[];
extern const char REPLACEALL_ABBREV[];

extern const char REPLACEONCE_NAME[];
extern const char REPLACEONCE_ABBREV[];

extern const char REQUESTORDER_NAME[];
extern const char REQUESTORDER_ABBREV[];

extern const char RIGHTMARGIN_NAME[];
extern const char RIGHTMARGIN_ABBREV[];

extern const char SAVE_NAME[];
extern const char SAVE_ABBREV[];

extern const char SAVEAS_NAME[];
extern const char SAVEAS_ABBREV[];

extern const char SAVEAUTOPREFS_NAME[];
extern const char SAVEAUTOPREFS_ABBREV[];

extern const char SAVECLIP_NAME[];
extern const char SAVECLIP_ABBREV[];

extern const char SAVEDEFPREFS_NAME[];
extern const char SAVEDEFPREFS_ABBREV[];

extern const char SAVEMACRO_NAME[];
extern const char SAVEMACRO_ABBREV[];

extern const char SAVEPREFS_NAME[];
extern const char SAVEPREFS_ABBREV[];

extern const char SEARCHBACK_NAME[];
extern const char SEARCHBACK_ABBREV[];

extern const char SELECTDOC_NAME[];
extern const char SELECTDOC_ABBREV[];

extern const char SETBOOKMARK_NAME[];
extern const char SETBOOKMARK_ABBREV[];

extern const char SHIFT_NAME[];
extern const char SHIFT_ABBREV[];

extern const char SHIFTTABS_NAME[];
extern const char SHIFTTABS_ABBREV[];

extern const char STATUSBAR_NAME[];
extern const char STATUSBAR_ABBREV[];

extern const char SUSPEND_NAME[];
extern const char SUSPEND_ABBREV[];

extern const char SYNTAX_NAME[];
extern const char SYNTAX_ABBREV[];

extern const char SYSTEM_NAME[];
extern const char SYSTEM_ABBREV[];

extern const char TABS_NAME[];
extern const char TABS_ABBREV[];

extern const char TABSIZE_NAME[];
extern const char TABSIZE_ABBREV[];

extern const char THROUGH_NAME[];
extern const char THROUGH_ABBREV[];

extern const char TOGGLESEOF_NAME[];
extern const char TOGGLESEOF_ABBREV[];

extern const char TOGGLESEOL_NAME[];
extern const char TOGGLESEOL_ABBREV[];

extern const char TOLOWER_NAME[];
extern const char TOLOWER_ABBREV[];

extern const char TOUPPER_NAME[];
extern const char TOUPPER_ABBREV[];

extern const char TURBO_NAME[];
extern const char TURBO_ABBREV[];

extern const char UNDELLINE_NAME[];
extern const char UNDELLINE_ABBREV[];

extern const char UNDO_NAME[];
extern const char UNDO_ABBREV[];

extern const char UNLOADMACROS_NAME[];
extern const char UNLOADMACROS_ABBREV[];

extern const char UNSETBOOKMARK_NAME[];
extern const char UNSETBOOKMARK_ABBREV[];

extern const char UTF8_NAME[];
extern const char UTF8_ABBREV[];

extern const char UTF8AUTO_NAME[];
extern const char UTF8AUTO_ABBREV[];

extern const char UTF8IO_NAME[];
extern const char UTF8IO_ABBREV[];

extern const char VERBOSEMACROS_NAME[];
extern const char VERBOSEMACROS_ABBREV[];

extern const char VISUALBELL_NAME[];
extern const char VISUALBELL_ABBREV[];

extern const char WORDWRAP_NAME[];
extern const char WORDWRAP_ABBREV[];


/* These are extras that are very useful in the default menus and key bindings. */
extern const char PLAYONCE_ABBREV[];
extern const char MIDDLEVIEW_ABBREV[];
extern const char SHIFTLEFT_ABBREV[];

/* This is the NULL-terminated, ordered list of names, useful for help etc. */

extern const char * const command_names[ACTION_COUNT+1];

/* This file was automatically generated by info2src.pl. */
